@@ -33,17 +33,11 @@ sub get_foreign_keys{
 
 1;
 
-
-
-=pod
+__END__
 
 =head1 NAME
 
-FabForce::DBDesigner4::SQL::Utils
-
-=head1 VERSION
-
-version 0.31
+FabForce::DBDesigner4::SQL::Utils - some utility functions for SQL generation
 
 =head1 SYNOPSIS
 
@@ -54,10 +48,6 @@ version 0.31
 As each database system has its own syntax, it is important to provide functions
 for each system.
 
-=head1 NAME
-
-FabForce::DBDesigner4::SQL::Utils - some utility functions for SQL generation
-
 =head1 METHODS
 
 =head2 get_foreign_keys
@@ -73,22 +63,4 @@ Copyright (C) 2005 - 2009 by Renee Baecker
 This program is free software; you can redistribute it and/or
 modify it under the terms of the Artistic License version 2.0.
 
-=cut
-
-=head1 AUTHOR
-
-Renee Baecker <module@renee-baecker.de>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is Copyright (c) 2010 by Renee Baecker.
-
-This is free software, licensed under:
-
-  The Artistic License 2.0
-
-=cut
-
-
-__END__
-
+=cut
\ No newline at end of file
